@@ -30,7 +30,7 @@ class SimpleClient:
         self.exc.delete_lookup_set(name)
 
     def list_lookup_sets(self):
-        self.exc.list_lookup_sets()
+        return self.exc.list_lookup_sets()
 
     def add_to_lookup(self, table, key, value):
         self.exc.add_to_lookup(table, key, value)
@@ -39,7 +39,7 @@ class SimpleClient:
         self.exc.delete_from_lookup(table, key)
 
     def list_lookup_values(self, table):
-        self.exc.list_lookup_sets(table)
+        return self.exc.list_lookup_sets(table)
 
     def delete_lookup(self, name):
         self.exc.deregister_lookup(name)
@@ -82,7 +82,10 @@ class Matrix:
             'X-StreamSQL-Admin-Key': self.__apikey
         }
         resp = requests.get(self.__host+endpoint, params=params, headers=headers)
-        return json.loads(resp.text)
+        try:
+            return json.loads(resp.text)
+        except:
+            return []
 
     def list_entities(self, name):
         endpoint = "/api/matrix/entities"
@@ -93,7 +96,10 @@ class Matrix:
             'X-StreamSQL-Admin-Key': self.__apikey
         }
         resp = requests.get(self.__host + endpoint, params=params, headers=headers)
-        return json.loads(resp.text)
+        try:
+            return json.loads(resp.text)
+        except:
+            return []
 
     def get_nearest_neighbor(self, name, entity, num, vector=False):
         endpoint = "/api/matrix/nn"
@@ -109,7 +115,10 @@ class Matrix:
             'X-StreamSQL-Admin-Key': self.__apikey
         }
         resp = requests.get(self.__host + endpoint, params=params, headers=headers)
-        return json.loads(resp.text)
+        try:
+            return json.loads(resp.text)
+        except:
+            return []
 
     def get_entity_vectors(self, name, entities):
         endpoint = "/api/matrix/entities/vectors"
@@ -121,7 +130,10 @@ class Matrix:
             'X-StreamSQL-Admin-Key': self.__apikey
         }
         resp = requests.get(self.__host + endpoint, params=params, headers=headers)
-        return json.loads(resp.text)
+        try:
+            return json.loads(resp.text)
+        except:
+            return {}
 
     def store_tree(self, name):
         endpoint = "/api/matrix/store"
