@@ -81,12 +81,16 @@ class Executor:
 
         requests.delete(self.host + "/api/lookup/table?table=" + name, headers=headers)
 
-    def list_lookup_sets(self):
+    def list_lookup_sets(self, table):
         headers = {
             'X-StreamSQL-Admin-Key': self.apikey
         }
 
-        requests.get(self.host + "/api/lookup/table", headers=headers)
+        resp = requests.get(self.host + "/api/lookup/values?table=" + table, headers=headers)
+        try:
+            return json.loads(resp.text)
+        except:
+            return []
 
     def add_to_lookup(self, table, key, value):
         headers = {
@@ -114,7 +118,11 @@ class Executor:
             'X-StreamSQL-Admin-Key': self.apikey
         }
 
-        requests.get(self.host + "/api/lookup/values?table="+table, headers=headers)
+        resp = requests.get(self.host + "/api/lookup/values?table="+table, headers=headers)
+        try:
+            return json.loads(resp.text)
+        except:
+            return []
 
     def deregister_transformation(self, name):
         """
